function ms = addmut(M,n,nloci,SMM,a,b,anc)
%ms = addmut(M,n,nloci,SMM,a,b,anc)
%returns ms = matrix with nloc cols simulating the STR rpt-size of each node in M
%M = (2n-1)*4 matrix storing binary coalescent tree
%n = number of chromosomes in observed sample
%nloci = number of STR loci typed

%M defined as:
%First n rows = terminal nodes
%Next (n-1) rows = internal nodes.
%First col = time (going backwards) in whatever units, since start
%2nd col =  index of father
%3rd col = index of right descendent
%4th col = index of left descendent

%Note that nodes n+1..2n-1 are ordered in temporal order
%This means we can simply step backwards down the list of nodes

ms=zeros(2*n-1,nloci);				%will store STR rpt sizes
if SMM=='L-SMM', ms(2*n-1,:) = anc; end		%place anc haplo in MRCA, if we're using LLD-SMM

for i=(2*n-2):-1:1
  t=M(M(i,2),1) - M(i,1);		%time between current node and it's father
  for j=1:nloci
    if SMM=='S-SMM'
      ms(i,j) = ms(M(i,2),j) +rpois(a(j)*t/2) -rpois(a(j)*t/2);	%simulates STR-rpt under S-SMM, given t and mu for locus
    else
      ms(i,j) = LLD_sim(t,ms(M(i,2),j),a(j),b(j));				%simulates STR-rpt under LLD-SMM, given t and MRCA haplo
    end
  end
end
