function ASD = calcASD(M,anc,Freq)
%function ASD = calcASD(M,anc,Freq)
%Returns the value of ASD based on data in matrix M (each row is a sampled
%individual, each column is a different STR locus, each cell is the
%corresponding STR repeat size) and assumed MRCA haplotype stored in 'anc'.
%If Freq is specified, then M represents a matrix of different haplotypes,
%and Freq gives the counts of each haplotype found in the sample

[nhap,nloc] = size(M);
if nargin<3
    Freq = ones(nhap,1);
end

ASD = 0;
for i=1:nhap
    ASD = ASD + Freq(i).*sum( (M(i,:) - anc).^2 );
end
ASD = ASD/sum(Freq)/nloc;
