function ASD = simASD(MCruns, T, n, nloci, SMM, Rgrowth, mua, mub, anc);
%returns ASD = simulated vector of ASD values under model specified
%MCruns = number of Monte Carlo runs to do
%T = TMRCA (in gens)
%n = number of chromosomes in observed sample
%nloci = number of STR loci typed
%SMM specifies Y-STR mutation model
%Rgrowth specifies growth model
%mua = intercept under LLD-SMM; or = vector of mutation rates for each STR locus under S-SMM
%mub = slope (using STR repeat size as variate) under LLD-SSM, not used under S-SMM
%anc = vector giving MRCA haplotype under LLD-SSM, not used under S-SMM

ASD = zeros(MCruns,1);
iMRCA = 2*n-1;		%gives row in M refering to MRCA - needed if Rgrowth not 'star'
if SMM=='L-SMM'
  ANC = ones(n,1)*anc;	%gives matrix needed for subtraction from ms if SMM='LLD-SMM'
end
%convert mua and mub to vectors, if need be
if length(mua)==1
  mua = ones(1,nloci)*mua;
end
if length(mub)==1
  mub = ones(1,nloci)*mub;
end

for i=1:MCruns
  if isstr(Rgrowth)
    %n separate lineages, simulate final haplos for each one
    ms = zeros(n,nloci);		%will store final STR rpt values
    for j=1:n
    for k=1:nloci
      if SMM=='S-SMM'
        ms(j,k) = rpois(mua(k)*T/2) - rpois(mua(k)*T/2);	%simulates STR-rpt under S-SMM, given T and mu for locus
      else
        ms(j,k) = LLD_sim(T,anc(k),mua,mub);				%simulates STR-rpt under LLD-SMM, given T and MRCA haplo
      end
    end
    end
  else
    %growth model: lineages linked in a tree that needs to be simulated and stored in M
    if Rgrowth<=1e-10                           %very low values of Rgrowth treated as =0
      M = standard(n);					        %simulates standard coalescent
    else
      M = growth(n,Rgrowth);					%simulates coalescent-with-growth (in units of N(current))
    end
    M(:,1) = M(:,1)./M(iMRCA,1).*T;		    %converts tree to be in units of T
    ms = addmut(M,n,nloci,SMM,mua,mub,anc);	%adds mutations, under either S_SMM or LLD-SMM
  end
  %work out simulated ASD
  if SMM=='S-SMM'
    ASD(i) = mean(mean( ms(1:n,:).^2 ));
  else
    ASD(i) = mean(mean( (ms(1:n,:)-ANC).^2 ));
  end
end
