function M = standard(n)
%function M = standard(n)
%Simulates a standard coalescent tree (in units of N gens, where N=No. chromosomes in pop), for n sampled at tip
%Simulates coalescent tree as M where:
%First n rows = terminal nodes
%Next (n-1) rows = internal nodes.
%First col = time (going backwards) in units of (N=total pop size), since start
%2nd col =  index of father
%3rd col = index of right descendent
%4th col = index of left descendent
  %P(coal in any one gen) = (1/N) * npairs
  %Therefore, time to next coal has exp. distn with mean N/npairs, or 1/npairs in units of N

M = zeros(2*n-1,4);

X=(1:n); nX=n;    		%stores list of indices for currently "active" lines

for i=n+1:2*n-1		%build up each coalescent event until TMRCA
  M(i,1) = M(i-1,1) -log(rand)*2/nX/(nX-1);
  %choose descendents
  d1 = X(ceil(rand*nX));  X = X(X~=d1);
  nX=nX-1;
  d2 = X(ceil(rand*nX));
  X(X==d2) = i;		%i.e. get rid of d1 from X, put "i" instead of d2 into X
  M(i,3)=d1;   M(i,4)=d2;
  M(d1,2)=i;  M(d2,2)=i;
end
